/*
 * Copyright 2004 Berend "Kirk" Wouda
 *
 * This file is part of R3n4m0r.
 *
 * R3n4m0r is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * R3n4m0r is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with R3n4m0r; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */


// Import the IO classes
import java.io.*;

/**
 * R3n4m0r
 *
 * This class renames all the files in the given folder to increasing numbers in the format ###.jpg
*/
public class R3n4m0r {
	public static void main(String[] args) {
		// Annoy the user.
		System.out.println("R3n4m0r v1.01 by Kirk");
		System.out.println();

		// Check for arguments.
		if(args.length == 1) {
			// Make a File out of the passed folder.
			File folder = new File(args[0]);

			// Check whether this file exists.
			if(!folder.exists()) {
				System.out.println("Don't try to bend the folder. Know it is bent. Remember: There is no folder.");
				System.exit(0);
			}

			// Check whether this file is a folder.
			if(!folder.isDirectory()) {
				System.out.println("That folder is not a folder, silly.");
				System.exit(0);
			}

			// Get the files in that folder.
			File[] files = folder.listFiles();

			// The numbers the files will get.
			int index2 = 1;

			// Go through the files and rename them.
			for(int index = 0; index < files.length; index++) {
				// Check whether this filke is not a folder.
				if(!files[index].isDirectory()) {
					// Strings for help with constructing the file number:
					String name = "" + (index2);
					String number = "";

					// We need to pad the numbers with zeroes.
					if(name.length() == 1)  number = "00" + name;
					else if(name.length() == 2)  number = "0" + name;
					else if(name.length() == 3)  number = name;
					else {
						System.out.println("There are more than 999 files in this folder. Only 999 have been renamed. Which ones, cannot be said.");
						System.exit(0);
					}

					// Retrieve the current file and rename it.
					if(!files[index].renameTo(new File(folder, "" + number + ".jpg"))) {
						System.out.println("File " + files[index].toString() + " didn't want be renamed. Or actually, Windows didn't want this file to be renamed. Or whatever your OS is. Moving on...");
					}
					else  index2++;
				}
			}

			// Annoy the user.
			System.out.println("Your porno has successfully been renamed.");
		}
		else {
			// Wrong amount of arguments. Print usage.
			System.out.println("  Usage:");
			System.out.println();
			System.out.println("    R3n4m0r folder");
		}
	}
}